@@ -16,13 +16,13 @@ class RPCRegister:
         self._m_heads['api-token'] = self._access_token if self._access_token else ''
         self._sc_uri = rpcConfig['uri']
 
-    def RegisterRPC(self, serviceClass):
-        self._registerService(serviceClass)
+    def RegisterRPC(self):
+        self._registerService()
     
     def RegisterMethod(self, pk ,serviceClass):
         self._registerMehotd(pk, serviceClass)
 
-    def _registerService(self, serviceClass):
+    def _registerService(self):
         m_service_post_data = ''
         m_count = 0
         # 生成注册服务参数.
